@@ -1,6 +1,6 @@
-/* $Id: main.c 1493 2007-12-12 19:33:26Z chpe $ */
 /*
- * Copyright (c) 2004 Noah Levitt
+ * Copyright © 2004 Noah Levitt
+ * Copyright © 2007, 2008 Christian Persch
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -17,28 +17,44 @@
  * 59 Temple Place, Suite 330, Boston, MA 02110-1301  USA
  */
 
-#include "config.h"
+#include <config.h>
 
-#include <gtk/gtk.h>
 #include <stdlib.h>
-#include"gucharmap-intl.h"
-#include "gucharmap-window.h"
-#include "gucharmap-mini-fontsel.h"
-#include "gucharmap-settings.h"
 
-gint
-main (gint argc, gchar **argv)
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+
+#include <gucharmap/gucharmap.h>
+#include "gucharmap-settings.h"
+#include "gucharmap-window.h"
+ 
+static gboolean
+option_version_cb (const gchar *option_name,
+                   const gchar *value,
+                   gpointer     data,
+                   GError     **error)
+{
+  g_print ("%s %s\n", _("GNOME Character Map"), VERSION);
+
+  exit (EXIT_SUCCESS);
+  return FALSE;
+}
+
+int
+main (int argc, char **argv)
 {
   GtkWidget *window;
   GdkScreen *screen;
-  gint monitor;
+  int monitor;
   GdkRectangle rect;
   GError *error = NULL;
-  gchar *new_font = NULL;
+  char *font = NULL;
   GOptionEntry goptions[] =
   {
-    { "font", 0, 0, G_OPTION_ARG_STRING, &new_font,
+    { "font", 0, 0, G_OPTION_ARG_STRING, &font,
       N_("Font to start with; ex: 'Serif 27'"), N_("FONT") },
+    { "version", 0, G_OPTION_FLAG_HIDDEN | G_OPTION_FLAG_NO_ARG, 
+      G_OPTION_ARG_CALLBACK, option_version_cb, NULL, NULL },
     { NULL }
   };
 
@@ -46,6 +62,11 @@ main (gint argc, gchar **argv)
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
+#ifdef HAVE_GCONF
+  /* GConf uses ORBit2 which need GThread. See bug #565516 */
+  g_thread_init (NULL);
+#endif
+
   if (!gtk_init_with_args (&argc, &argv, "", goptions, GETTEXT_PACKAGE, &error))
     {
       g_printerr ("%s\n", error->message);
@@ -55,51 +76,32 @@ main (gint argc, gchar **argv)
     }
 
   gucharmap_settings_initialize ();
-  g_set_application_name (_("Gucharmap"));
-  gtk_window_set_default_icon_name ("gucharmap");
+
+  g_set_application_name (_("Character Map"));
+  gtk_window_set_default_icon_name (GUCHARMAP_ICON_NAME);
 
   window = gucharmap_window_new ();
-  gucharmap_window_set_text_to_copy_visible (GUCHARMAP_WINDOW (window), TRUE);
-  gucharmap_window_set_font_selection_visible (GUCHARMAP_WINDOW (window), TRUE);
-  gucharmap_window_set_file_menu_visible (GUCHARMAP_WINDOW (window), TRUE);
+  g_signal_connect (window, "destroy",
+                    G_CALLBACK (gtk_main_quit), NULL);
 
   screen = gtk_window_get_screen (GTK_WINDOW (window));
   monitor = gdk_screen_get_monitor_at_point (screen, 0, 0);
   gdk_screen_get_monitor_geometry (screen, monitor, &rect);
   gtk_window_set_default_size (GTK_WINDOW (window), rect.width * 9/16, rect.height * 9/16);
 
-  gucharmap_settings_add_window (GTK_WINDOW (window));
+  /* No --font argument, use the stored font (if any) */
+  if (!font)
+    font = gucharmap_settings_get_font ();
 
-  /* make the starting font 50% bigger than the default font */
-  if (new_font == NULL) /* new_font could be set by command line option */
+  if (font)
     {
-      GucharmapMiniFontSelection *fontsel = gucharmap_window_get_mini_font_selection (GUCHARMAP_WINDOW (window));
-      gint default_size = PANGO_PIXELS (2.0 * pango_font_description_get_size (window->style->font_desc));
-      gucharmap_mini_font_selection_set_default_font_size (fontsel, default_size);
-
-      new_font = gucharmap_settings_get_font ();
-      if (new_font)
-        {
-          PangoFontDescription *fd = pango_font_description_from_string (new_font);
-
-          /* revert to default font size */
-          if (0 == pango_font_description_get_size (fd))
-            gucharmap_mini_font_selection_reset_font_size (fontsel);
-	  else
-	    gucharmap_mini_font_selection_set_font_name (fontsel, new_font);
-
-          pango_font_description_free (fd);
-	  g_free (new_font);
-        }
-      else
-        gucharmap_mini_font_selection_reset_font_size (fontsel);
+      gucharmap_window_set_font (GUCHARMAP_WINDOW (window), font);
+      g_free (font);
     }
 
-  g_signal_connect (G_OBJECT (window), "destroy", G_CALLBACK (gtk_main_quit), NULL);
+  gucharmap_settings_add_window (GTK_WINDOW (window));
 
-  gucharmap_table_grab_focus (GUCHARMAP_WINDOW (window)->charmap->chartable);
-
-  gtk_widget_show (window);
+  gtk_window_present (GTK_WINDOW (window));
 
   gtk_main ();
 
